<?php

return [
    'menu' => [
        'einvoice' => 'E-Invoice',
        'einvoiceSettings' => 'E-Invoice Settings',
    ],
    'settingForm' => [
        'electronicAddress' => 'Electronic Address',
        'electronicAddressScheme' => 'Electronic Address Scheme',
        'companyID' => 'Company ID',
        'companyIDScheme' => 'Company ID Scheme',
    ],
    'companyAddressNote' => 'This module uses the country from the Business Address. If you have not selected a country, please choose one from the :link',
    'generateEInvoice' => 'E-Invoice',
    'clientElectronicAddressNotSet' => 'Client Electronic Address or Electronic Address Scheme is not set. Please set it first.',
    'clientElectronicAddressSetNote' => 'Please set the :client electronic address and electronic address scheme first to generate the E-Invoice.',
    'settingsNote' => 'Please set the E-Invoice settings first for the company.',
];
